@@ -3,22 +3,21 @@ package Compress::Zlib;
 
 require 5.004 ;
 require Exporter;
-use AutoLoader;
 use Carp ;
 use IO::Handle ;
 use Scalar::Util qw(dualvar);
 
-use IO::Compress::Base::Common 2.026 ;
-use Compress::Raw::Zlib 2.026 ;
-use IO::Compress::Gzip 2.026 ;
-use IO::Uncompress::Gunzip 2.026 ;
+use IO::Compress::Base::Common 2.032 ;
+use Compress::Raw::Zlib 2.032 ;
+use IO::Compress::Gzip 2.032 ;
+use IO::Uncompress::Gunzip 2.032 ;
 
 use strict ;
 use warnings ;
 use bytes ;
-our ($VERSION, $XS_VERSION, @ISA, @EXPORT, @EXPORT_OK, %EXPORT_TAGS, $AUTOLOAD);
+our ($VERSION, $XS_VERSION, @ISA, @EXPORT, @EXPORT_OK, %EXPORT_TAGS);
 
-$VERSION = '2.026';
+$VERSION = '2.032';
 $XS_VERSION = $VERSION; 
 $VERSION = eval $VERSION;
 
@@ -46,16 +45,6 @@ BEGIN
     *zlib_version = \&Compress::Raw::Zlib::zlib_version;
 }
 
-sub AUTOLOAD {
-    my($constname);
-    ($constname = $AUTOLOAD) =~ s/.*:://;
-    my ($error, $val) = Compress::Raw::Zlib::constant($constname);
-    Carp::croak $error if $error;
-    no strict 'refs';
-    *{$AUTOLOAD} = sub { $val };
-    goto &{$AUTOLOAD};
-}
-
 use constant FLAG_APPEND             => 1 ;
 use constant FLAG_CRC                => 2 ;
 use constant FLAG_ADLER              => 4 ;
@@ -462,7 +451,7 @@ sub inflate
 
 package Compress::Zlib ;
 
-use IO::Compress::Gzip::Constants 2.026 ;
+use IO::Compress::Gzip::Constants 2.032 ;
 
 sub memGzip($)
 {
@@ -1487,7 +1476,7 @@ See the Changes file.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 1995-2010 Paul Marquess. All rights reserved.
+Copyright (c) 1995-2011 Paul Marquess. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
